{%- set os=grains['os'] -%}

laradev-unzip:
  pkg.installed:
    - name: unzip
laradev-php:
  pkg.installed:
    - name: php
laradev-composer:
  pkg.installed:
    - name: composer
laradev-php-fpm:
  pkg.installed:
    - name: php-fpm
  service.running:
    - name: php-fpm
    - enable: true
    - watch:
      - file: /etc/php/php.ini

laradev-sqlite:
  pkg.installed:
    - name: sqlite
laradev-phpsqlite:
  pkg.installed:
    - name: php-sqlite
laradev-phpxsl:
  pkg.installed:
    - name: php-xsl
laradev-phpgd:
  pkg.installed:
    - name: php-gd

database-directory:
  file.directory:
    - name: /sites/databases
    - makedirs: true
/var/lib/mysql:
  file.symlink:
      - target: /sites/databases/
laradev-mysql:
  pkg.installed:
    - name: mariadb
laradev-mysql-python:
  pkg.installed:
    - name: mysql-python
laradev-init-mysql:
  cmd.run:
    - name: mysql_install_db --user=mysql --basedir=/usr --datadir=/sites/databases/
    - unless: 'test -e /sites/databases/mysql'
laradev-mysql-service:
  service.running:
    - name: mysqld
    - enable: true

#create laradev user
laradev-user:
  mysql_user.present:
    - name: laradev
    - host: "localhost"
    - password: "{%- include 'secure/passwords/laradev_db_password.txt' -%}"
    - connection_user: root

laradev-nginx-conf:
  file.managed:
    - name: /etc/nginx/nginx.conf
    - source: salt://roles/maintain/nginx-proxy/nginx.conf
    - user: root
    - group: root
    - mode: 644

{%- if pillar['laradev'] is defined -%}
{%- for server in pillar['laradev'] %}
/etc/nginx/conf.d/laradev-{{ server }}.conf:
  file.managed:
    - makedirs: true
    - source: salt://roles/maintain/laradev/nginx.conf
    - user: root
    - group: root
    - mode: 644
    - template: jinja
    - context:
      server: {{ server }}

{% endfor %}
{% endif %}

/etc/php/php.ini:
  file.managed:
    - source: salt://roles/maintain/laradev/php.ini
    - user: root
    - group: root
    - mode: 644

/root/scripts/git_branches.sh:
  file.managed:
    - source: salt://roles/maintain/laradev/git_branches.sh
    - user: root
    - group: root
    - mode: 644
    - template: jinja
      password: "{%- include 'secure/passwords/laradev_db_password.txt' -%}"

/root/scripts/laradev-branch-nginx.template:
  file.managed:
    - source: salt://roles/maintain/laradev/branch.conf
    - user: root
    - group: root
    - mode: 644

"/lib/systemd/system/git_branches.service":
  file.managed:
    - source: salt://roles/maintain/laradev/git_branches.service
    - user: root
    - group: root
    - mode: 644

"/lib/systemd/system/git_branches.timer":
  file.managed:
    - source: salt://roles/maintain/laradev/git_branches.timer
    - user: root
    - group: root
    - mode: 644

"git_branches-reload":
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: /lib/systemd/system/*

"git_branches.timer":
  service.running:
    - enable: true

/root/.ssh/config:
  file.managed:
    - source: salt://roles/maintain/laradev/ssh_config
    - user: root
    - group: root
    - mode: 644

/root/.ssh/git_actcur:
  file.managed:
    - source: salt://secure/keys/git/git_actcur
    - user: root
    - group: root
    - mode: 600
